""""
Copyright: Pierre Dubertrand
Author: Pierre Dubertrand

Name-US: Select Corona Materials by Type
Description-US: Selects all Corona materials of the chosen type

"""

import c4d

CORONA_STR_MATERIAL = 1032100
CORONA_STR_MATERIAL_LAYERED = 1035110
CORONA_STR_MATERIAL_SELECT = 1052986
CORONA_STR_MATERIAL_LIGHT = 1035372
CORONA_STR_MATERIAL_SHADOWCATCHER = 1039477
CORONA_STR_MATERIAL_VOLUME = 1035373
CORONA_STR_MATERIAL_RAYSWITCH = 1036210
CORONA_STR_MATERIAL_SKIN = 1040777
CORONA_STR_MATERIAL_HAIR = 1039479
CORONA_STR_MATERIAL_PHYSICAL = 1056306
CORONA_STR_MATERIAL_SLICER = 1058679
CORONA_STR_MATERIAL_SCANNED = 1060061

class SelectCoronaMtlDlg(c4d.gui.GeDialog):

    def __init__(self):

        self.filter_mode = CORONA_STR_MATERIAL_PHYSICAL
        self.userCancel = False
        self.userOK = False

    def InitValues(self):

        self.SetInt32(1002, self.filter_mode)
        
        return True

    def CreateLayout(self):

        self.SetTitle("Select Corona Material by Type")

        # group layout
        self.GroupBegin(id=1000, flags=c4d.BFH_CENTER | c4d.BFV_CENTER, cols=2,
                        rows=1, title="Settings",
                        groupflags=c4d.BFV_GRIDGROUP_EQUALROWS)

        # group settings
        self.GroupBorderSpace(5, 5, 5, 5)

        # group items
        self.AddStaticText(
            1001, c4d.BFH_LEFT | c4d.BFV_FIT, name="Material Type")
        self.AddComboBox(1002, c4d.BFH_FIT | c4d.BFV_FIT)

        # dropdown menu items
        self.AddChild(1002, CORONA_STR_MATERIAL_PHYSICAL, "Physical Material")
        self.AddChild(1002, CORONA_STR_MATERIAL, "Legacy Material")
        self.AddChild(1002, CORONA_STR_MATERIAL_LAYERED, "Layered Material")
        self.AddChild(1002, CORONA_STR_MATERIAL_SELECT, "Select Material")
        self.AddChild(1002, CORONA_STR_MATERIAL_SKIN, "Skin Material")
        self.AddChild(1002, CORONA_STR_MATERIAL_HAIR, "Hair Material")
        self.AddChild(1002, CORONA_STR_MATERIAL_LIGHT, "Light Material")
        self.AddChild(1002, CORONA_STR_MATERIAL_RAYSWITCH, "Ray Switcher Material")
        self.AddChild(1002, CORONA_STR_MATERIAL_SHADOWCATCHER, "Shadow Catcher Material")
        self.AddChild(1002, CORONA_STR_MATERIAL_VOLUME, "Volume Material")
        self.AddChild(1002, CORONA_STR_MATERIAL_SLICER, "Slicer Material")
        self.AddChild(1002, CORONA_STR_MATERIAL_SCANNED, "Scanned Material")

        self.GroupEnd()

        self.AddDlgGroup(c4d.DLG_OK | c4d.DLG_CANCEL)

        return True

    def Command(self, id, msg):

        if id == c4d.DLG_OK:
            self.filter_mode = self.GetInt32(1002)
            self.userOK = True
            self.Close()
        elif id == c4d.DLG_CANCEL:
            self.userCancel = True
            self.Close()

        return True

def main():
    
    doc = c4d.documents.GetActiveDocument()
    
    mtls = doc.GetActiveMaterials()

    doc.StartUndo()

    # Here the dialog window to choose the material type to select
    dlg = SelectCoronaMtlDlg()

    dlg.Open(dlgtype=c4d.DLG_TYPE_MODAL, xpos=-2, ypos=-2)

    if dlg.userCancel == True:
        print("[Select Corona Materials by Type] Operation canceled by the user")
        return
    elif dlg.userOK == True:
        if mtls:
            [doc.SetSelection(mtl,c4d.SELECTION_SUB) for mtl in mtls]
        for mtl in doc.GetMaterials():
            if mtl.CheckType(dlg.filter_mode):
                doc.AddUndo(c4d.UNDOTYPE_BITS,mtl)
                doc.SetSelection(mtl,c4d.SELECTION_ADD)
    else:
        print("[Select Corona Materials by Type] Window closed : operation aborted")
        return

    doc.EndUndo()
    c4d.EventAdd()


# Execute main()
if __name__ == '__main__':
    main()