"""
Copyright: Pierre Dubertrand
Author: Pierre Dubertrand

Name-en-US: Sort Corona Materials by Type
Description-en-US: Sorts materials by type and add them to a layer


"""

import c4d


def recursive_search_filter(op, name=""):
    while op:
        if op.GetName() == name:
            return op
        else:
            recursive_search_filter(op.GetDown())
            op = op.GetNext()
    return None


def layer_ops(doc, layer_name, obj):
    doc_layers = doc.GetLayerObjectRoot()  # Get insertion point in document layers
    existing_layer = recursive_search_filter(doc_layers.GetDown(), layer_name)
    if existing_layer:
        assign_to_layer(doc, existing_layer, obj)
    else:
        new_layer = create_layer(doc, layer_name)
        assign_to_layer(doc, new_layer, obj)


def assign_to_layer(doc, layer, obj):
    doc.AddUndo(c4d.UNDOTYPE_CHANGE, obj)
    obj.SetLayerObject(layer)


def create_layer(doc, layer_name):
    layer = c4d.documents.LayerObject()
    layer[c4d.ID_BASELIST_NAME] = layer_name
    doc_layers = doc.GetLayerObjectRoot()  # Get insertion point in document layers
    # Insert the new layer as the last in the list
    doc_layers.InsertLast(layer)
    doc.AddUndo(c4d.UNDOTYPE_NEWOBJ, layer)
    return layer


def main():

    doc = c4d.documents.GetActiveDocument()

    mtls = doc.GetActiveMaterials()

    doc.StartUndo()

    if mtls:
        w = "The command will run on the selected materials, existing layers assignments will be LOST. Proceed ?"
    else:
        mtls = doc.GetMaterials()
        w = "No material selection. The command will run on ALL the materials in the scene and existing layers assignments will be LOST. Proceed ?"

    q = c4d.gui.QuestionDialog(w)

    if q:
        for mtl in mtls:
            if mtl.CheckType(1056306):  # Corona Physical Material
                layer_name = 'Corona Physical Material'
            elif mtl.CheckType(1032100):  # Corona Legacy Material
                layer_name = 'Corona Legacy Material'
            elif mtl.CheckType(1035110):  # Corona Layered Material
                layer_name = 'Corona Layered Material'
            elif mtl.CheckType(1035372):  # Corona Light Material
                layer_name = 'Corona Light Material'
            elif mtl.CheckType(1035373):  # Corona Volume Material
                layer_name = 'Corona Volume Material'
            elif mtl.CheckType(1039479):  # Corona Hair Material
                layer_name = 'Corona Hair Material'
            elif mtl.CheckType(1040777):  # Corona Skin Material
                layer_name = 'Corona Skin Material'
            elif mtl.CheckType(1052986):  # Corona Select Material
                layer_name = 'Corona Select Material'
            elif mtl.CheckType(1039477):  # Corona Shadow Catcher Material
                layer_name = 'Corona Shadow Catcher Material'
            elif mtl.CheckType(1036210):  # Corona Ray Switcher Material
                layer_name = 'Corona Ray Switcher Material'
            elif mtl.CheckType(1058679):  # Corona Slicer Material
                layer_name = 'Corona Slicer Material'
            elif mtl.CheckType(1060061):  # Corona Scanned Material
                layer_name = 'Corona Scanned Material'
            else:
                layer_name = 'Non-Corona materials'

            layer_ops(doc, layer_name, mtl)
    else:
        print("[Sort Corona Materials] Operation canceled by the user")
        return

    doc.EndUndo()
    c4d.EventAdd()


# Execute main()
if __name__ == '__main__':
    main()
