""""
Copyright: Pierre Dubertrand
Author: Pierre Dubertrand

Name-US: Update Normals Filtering
Description-US: Change Normals Filtering Mode to Roughness Modulation on selected materials

"""

import c4d
import os


doc = c4d.documents.GetActiveDocument()



class UpdateNormalsFilteringDlg(c4d.gui.GeDialog):

    def __init__(self):

        self.filter_mode = 2
        self.userCancel = False
        self.userOK = False

    def InitValues(self):

        self.SetInt32(1002, self.filter_mode)
        
        return True

    def CreateLayout(self):

        self.SetTitle("Update Normals Filtering")

        # group layout
        self.GroupBegin(id=1000, flags=c4d.BFH_CENTER | c4d.BFV_CENTER, cols=2,
                        rows=1, title="Settings",
                        groupflags=c4d.BFV_GRIDGROUP_EQUALROWS)

        # group settings
        self.GroupBorder(c4d.BORDER_WITH_TITLE_BOLD)
        self.GroupBorderSpace(5, 5, 5, 5)

        # group items
        self.AddStaticText(
            1001, c4d.BFH_LEFT | c4d.BFV_FIT, name="Filtering Mode")
        self.AddComboBox(1002, c4d.BFH_FIT | c4d.BFV_FIT)

        # dropdown menu items
        self.AddChild(1002, 0, "None")
        self.AddChild(1002, 1, "Linear")
        self.AddChild(1002, 2, "Roughness Modulation")

        self.GroupEnd()

        self.AddDlgGroup(c4d.DLG_OK | c4d.DLG_CANCEL)

        return True

    def Command(self, id, msg):

        if id == c4d.DLG_OK:
            self.filter_mode = self.GetInt32(1002)
            self.userOK = True
            self.Close()
        elif id == c4d.DLG_CANCEL:
            self.userCancel = True
            self.Close()

        return True


def update_normal_filtering(material: c4d.BaseMaterial, filter_mode: int, n: int):

    if material.GetType() == 1056306:  # Corona Physical Mtl
        doc.AddUndo(c4d.UNDOTYPE_CHANGE, material)
        material[c4d.CORONA_MATERIAL_NORMALS_FILTERING] = filter_mode
        n += 1
    return True


def main():

    mtls = doc.GetActiveMaterials()

    n = 0

    doc.StartUndo()

    if mtls:
        pass
    else:
        w = c4d.gui.QuestionDialog(
            'No material selected.\n\nUpdate all Corona Physical Materials in the scene ?')
        if w:
            mtls = doc.GetMaterials()
        else:
            print("[Update Normals Filtering] Operation aborted")
            return

    dlg = UpdateNormalsFilteringDlg()

    dlg.Open(dlgtype=c4d.DLG_TYPE_MODAL, xpos=-2, ypos=-2)

    if dlg.userCancel == True:
        print("[Update Normals Filtering] Operation canceled")
    elif dlg.userOK == True:
        # If no mtl selection, get all the scene materials
        for mtl in mtls:
            update_normal_filtering(mtl, dlg.filter_mode, n)    
    else:
        print("[Update Normals Filtering] Operation aborted")
        return
    
    if n > 0:
        # Message to console
        print(f'[Update Normals Filtering] : {n} materials were updated')

    doc.EndUndo()

    c4d.EventAdd()


if __name__ == '__main__':
    main()
